@@ -1,11 +1,11 @@
 export * from './aaa'
 export * from './api'
-export * from './app'
+export * from './project'
 export * from './common'
 export * from './forms'
 export * from './l10n'
 export * from './mail'
 export * from './screens'
 export * from './settings'
-export * from './sitemap'
+export * from './sidebar'
 export * from './storage'
